pub(super) fn maybe_run_jit_helper() -> Result<ControlFlow<()>>Available on Unix and crate feature
llvm only.Expand description
Runs the out-of-process JIT helper if this process was launched as one.
pub(super) fn maybe_run_jit_helper() -> Result<ControlFlow<()>>llvm only.Runs the out-of-process JIT helper if this process was launched as one.